@@ -15,7 +15,7 @@ require DynaLoader;
 		 d_usleep d_ualarm d_gettimeofday d_getitimer d_setitimer
 		 d_nanosleep);
 	
-$VERSION = '1.46';
+$VERSION = '1.48';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -317,6 +317,17 @@ Here is an example of using NVtime from C:
   myNVtime = INT2PTR(double(*)(), SvIV(*svp));
   printf("The current time is: %f\n", (*myNVtime)());
 
+=head1 DIAGNOSTICS
+
+=head2 negative time not invented yet
+
+You tried to use a negative time argument.
+
+=head2 internal error: useconds < 0 (unsigned ... signed ...)
+
+Something went horribly wrong-- the number of microseconds that cannot
+become negative just became negative.  Maybe your compiler is broken?
+
 =head1 CAVEATS
 
 Notice that the core time() maybe rounding rather than truncating.
